@@ -255,8 +255,11 @@ void Config::read()
     }
 }
 
-void Config::write()
+void Config::write( bool sync )
 {
+    QTime time;
+    time.start();
+
     writeProfiles();
     writeServiceMenu();
     writeAmarokScript();
@@ -306,9 +309,11 @@ void Config::write()
     }
     conf->writeEntry( "foundPrograms", data.environment.foundPrograms );
 
-    conf->sync();
+    if( sync ) conf->sync();
 
     emit configChanged();
+
+    logger->log( 1000, "wrote preferences: " + QString::number(time.elapsed()) );
 }
 
 void Config::readProfiles()
@@ -630,8 +635,12 @@ void Config::writeAmarokScript()
     }
 
     KStandardDirs* stdDirs = new KStandardDirs();
-    KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/soundKonverter.rb"), locateLocal("data","amarok/scripts/soundKonverter/soundKonverter.rb"), 0755, true );
-    KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/README"), locateLocal("data","amarok/scripts/soundKonverter/README"), -1, true );
+    if( !QFile::exists(locateLocal("data","amarok/scripts/soundKonverter/soundKonverter.rb")) ) {
+        KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/soundKonverter.rb"), locateLocal("data","amarok/scripts/soundKonverter/soundKonverter.rb"), 0755, true );
+    }
+    if( !QFile::exists(locateLocal("data","amarok/scripts/soundKonverter/README")) ) {
+        KIO::NetAccess::file_copy( stdDirs->findResource("data","soundkonverter/amarokscript/README"), locateLocal("data","amarok/scripts/soundKonverter/README"), -1, true );
+    }
     delete stdDirs;
 }
 
@@ -1349,24 +1358,24 @@ QStringList Config::getAllProfiles()
     return list;
 }
 
-bool Config::acceptFile( const QString& mimeType )
+bool Config::acceptFile( const QString& format )
 {
-    if( mimeType == "audio/x-wav" ) return true;
+    if( format == "audio/x-wav" || format == "wav" ) return true;
 
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
-        if( (*it).decoder != 0 && (*it).mime_types.findIndex(mimeType) != -1 ) {
-            return true;
+        if( (*it).mime_types.findIndex(format) != -1 || (*it).extensions.findIndex(format) != -1 ) { // we found it
+            if( (*it).decoder != 0 ) return true;
         }
     }
 
     return false;
 }
 
-bool Config::acceptReplayGainFile( const QString& mimeType )
+bool Config::acceptReplayGainFile( const QString& format )
 {
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
-        if( (*it).replaygain != 0 && (*it).mime_types.findIndex(mimeType) != -1 ) {
-            return true;
+        if( (*it).mime_types.findIndex(format) != -1 || (*it).extensions.findIndex(format) != -1 ) { // we found it
+            if( (*it).replaygain != 0 ) return true;
         }
     }
 
@@ -1376,9 +1385,9 @@ bool Config::acceptReplayGainFile( const QString& mimeType )
 QString Config::fileFilter( bool wav )
 {
     QString filter1;
-    if( wav ) filter1 += "*.wav";
+    if( wav ) filter1 += "*.wav *.WAV *.Wav";
     QString filter2;
-    if( wav ) filter2 += "\n*.wav *.WAV|wav " + i18n("files") + " (*.wav *.WAV)";
+    if( wav ) filter2 += "\n*.wav *.WAV *.Wav|wav " + i18n("files") + " (*.wav)";
     QString temp;
 
     for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
@@ -1386,7 +1395,7 @@ QString Config::fileFilter( bool wav )
             temp = "";
             for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
                 filter1 += " *." + (*b);
-                temp += " *." + (*b);
+                if( !temp.contains(*b,false) ) temp += " *." + (*b).lower();
             }
             //temp.stripWhiteSpace(); // NOTE doesn't work
             if( temp != "" && temp.length() < 80 ) {
@@ -1406,6 +1415,72 @@ QString Config::fileFilter( bool wav )
     return filter1 + "|" + i18n("all supported formats") + "\n*.*|" + i18n("all formats") + filter2;
 }
 
+QStringList Config::fileTypes( bool wav )
+{
+    QStringList types;
+    if( wav ) types.append( "wav" );
+    QString temp;
+
+    for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
+        if( (*a).decoder != 0 ) {
+            temp = "";
+            for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
+                if( !temp.contains(*b,false) ) temp.append( (*b).lower() + ", " );
+            }
+            if( temp != "" ) types.append( temp.left( temp.length()-2 ) );
+        }
+    }
+
+    return types;
+}
+
 QString Config::replayGainFilter()
-{}
+{
+    QString filter1;
+    QString filter2;
+    QString temp;
+
+    for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
+        if( (*a).replaygain != 0 ) {
+            temp = "";
+            for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
+                filter1 += " *." + (*b);
+                if( !temp.contains(*b,false) ) temp += " *." + (*b).lower();
+            }
+            //temp.stripWhiteSpace(); // NOTE doesn't work
+            if( temp != "" && temp.length() < 80 ) {
+                temp.remove( 0, 1 );
+                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files") + " (" + temp + ")";
+            }
+            else if( temp != "" ) {
+                temp.remove( 0, 1 );
+                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files");
+            }
+        }
+    }
+
+    filter1.stripWhiteSpace();
+    filter2.stripWhiteSpace();
+
+    return filter1 + "|" + i18n("all supported formats") + "\n*.*|" + i18n("all formats") + filter2;
+}
+
+QStringList Config::replayGainFileTypes()
+{
+    QStringList types;
+    QString temp;
+
+    for( QValueList<FormatItem>::Iterator a = formats.begin(); a != formats.end(); ++a ) {
+        if( (*a).replaygain != 0 ) {
+            temp = "";
+            for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
+                if( !temp.contains(*b,false) ) temp.append( (*b).lower() + ", " );
+            }
+            if( temp != "" ) types.append( temp.left( temp.length()-2 ) );
+        }
+    }
+
+    return types;
+}
+
 
