@@ -68,7 +68,7 @@ private:
 
 signals:
     void addFile( const QString& );
-    void addDir( const QString& );
+    void addDir( const QString&, const QStringList& filter = "" );
     void calcAllReplayGain( bool force );
     void removeAllReplayGain();
     void cancelProcess();
